#!/bin/sh
#
# GGI descent configuration script
# Wowzers! Look at all the options Penny!

cd Config
# default/other script
Ask="sh ./Choose.sh"



# Figure out what kind of system we are on:
system=`uname`
if [ "X$system" = "X" ]; then
  echo "uname failed!"
else
  echo System=$system
fi



# initialize a few things
cc="gcc"

# Default: full optimization:
optimize="-O2 -fomit-frame-pointer"

extraobjs=""
extralibs=""



# All the configuration options:
echo "/* GGI descent configuration created by Configure.sh */" >../sysconfig.h

D="#define "
U="#undef"

echo "$D SYSTEM_$system" >>../sysconfig.h

features=""

use_long64=0
# 'long'=64 bits?
if [ "`$Ask 'Is long a 64 bit integer on your machine ?' 'n'`" != "n" ]; then
	echo "$D HAVE_LONG_64" >>../sysconfig.h
	features="$features -DHAVE_LONG_64"
	use_long64=1

# 'long long'=64 bits?
elif [ "`$Ask 'Is long long a 64 bit integer on your machine ?' 'y'`" != "n" ]; then
	echo "$D HAVE_LONG_LONG_64" >>../sysconfig.h
	features="$features -DHAVE_LONG_LONG_64"
	use_long64=1
fi

#BYTE_ORDER
if [ "X$system" = "XOpenBSD" ]; then
#	OpenBSD: defined in <stdio.h> -> <sys/types.h> -> <machine/endian.h>
	echo "#include <stdio.h>" >>../sysconfig.h
elif [ "X$system" = "XLinux" ]; then
#	Linux: defined in <endian.h>
	echo "#include <endian.h>" >>../sysconfig.h
elif [ "`$Ask 'Is your machine little endian (intel) ?' 'y'`" != "n" ]; then
	echo "$D LITTLE_ENDIAN_MACHINE" >>../sysconfig.h
	features="$features -DLITTLE_ENDIAN_MACHINE"
fi
if [ "X$system" = "XOpenBSD" ] || [ "X$system" = "XLinux" ]; then
	echo "#if BYTE_ORDER==LITTLE_ENDIAN" >>../sysconfig.h
	echo "$D LITTLE_ENDIAN_MACHINE" >>../sysconfig.h
	echo "#endif" >>../sysconfig.h
fi


if [ "`$Ask 'Which datafiles, PC version or MAC version ? (p/m)' 'p'`" = "p" ]; then
	echo "$D PC_REGISTERED_15" >>../sysconfig.h
	features="$features -DPC_REGISTERED_15"
else
 	echo "$D MAC_REGISTERED_15" >>../sysconfig.h
	features="$features -DMAC_REGISTERED_15"
fi
echo "Note that only the 1.4a (PC) and 1.5 (PC/MAC) datafiles work (the datafiles of these versions are the same in the PC case)"

if [ "`$Ask 'Run locally (datafiles in ./Data ./Demos ./Players) ?' 'n'`" != "n" ]; then
	echo "$D LOCAL_DATA_FILES" >>../sysconfig.h
	features="$features -DLOCAL_DATA_FILES"
fi

if [ "`$Ask 'Do you want sound (using GSI) ?' 'y'`" != "n" ]; then
	echo "$D USE_SOUND" >>../sysconfig.h
	features="$features -DUSE_SOUND"
	features="$features -DUSE_OSS"
fi


if [ "`$Ask 'Do you want to compile in joystick support ? (not available)' 'n'`" != "n" ]; then
	echo "$D USE_JOYSTICK" >>../sysconfig.h
	features="$features -DUSE_JOYSTICK"
fi

# Check the compiler
cc=`$Ask 'What compiler do you want to use?' "$cc"`
optimize=`$Ask 'What optimization flags do you want to use?' "$optimize"`

# Create a new Makeflags file
echo
echo "Creating new Makeflags..."
sed <Makeflags.in >Makeflags \
	-e "s|^\\(SYSTEM =\\)\$|\\1 $system|" \
	-e "s|^\\(CC =\\)\$|\\1 $cc|" \
	-e "s|^\\(OPTIMIZE =\\)\$|\\1 $optimize|" \
	-e "s|^\\(FEATURES =\\)\$|\\1 $features|" \
	-e "s|^\\(EXTRALIBS =\\)\$|\\1 $extralibs|" \
	-e "s|^\\(SOUNDLIBS =\\)\$|\\1 $soundlibs|" \
	-e "s|^\\(EXTRAOBJS =\\)\$|\\1 $extraobjs|" \
	-e "s|^\\(USE_SNDSERVER =\\)\$|\\1 $use_sndserver|" \
	-e "s|^\\(SNDSERVER =\\)\$|\\1 $sndserver|"
echo

echo "To set install locations type 'make location'"
echo "Type 'make clean' and 'make' to build GGI descent"
